# Name: libsetuproi/director.py
# Purpose: Application-level director class
# Author: Ken McIvor <mcivor@iit.edu>
#
# Copyright 2006 Illinois Institute of Technology
#
# See the file "LICENSE" for information on usage and redistribution
# of this file, and for a DISCLAIMER OF ALL WARRANTIES.


__all__ = ['AppDirector']


class AppDirector:
    """
    Generic application-level director which manages frame creation,
    application exit, etc.
    """

    def __init__(self, view, frameClass, frameParent=None):
        self.view = view
        self.frames = []
        self.frameClass = frameClass
        self.frameParent = frameParent

    def createNewFrame(self):
        frame = self.frameClass(self.frameParent, self)
        self.frames.append(frame)
        frame.Show(True)
        return frame

    def removeFrame(self, frame):
        try:
            self.frames.remove(frame)
        except IndexError:
            pass

    def canClose(self):
        for frame in self.frames:
            if not frame.canClose():
                return self.view.askOkCancel('', 'Quit without saving?')
        return True

    def exitApplication(self):
        if self.canClose():
            for frame in self.frames:
                frame.Destroy()
