# Name: libsetuproi/roicmds.py
# Purpose: Commands which modify an RoiList
# Author: Ken McIvor <mcivor@iit.edu>
#
# Copyright 2006 Illinois Institute of Technology
#
# See the file "LICENSE" for information on usage and redistribution
# of this file, and for a DISCLAIMER OF ALL WARRANTIES.

import os.path
from libsetuproi.roilist import RoiList
from libsetuproi.command import Command, CommandError

__all__ = ['ModifyRoiCommand', 'LoadRoiCommand']


class ModifyRoiCommand(Command):
    DESCRIPTION = 'Modify ROI'

    def __init__(self, roiList, regionNumber, channelNumber, start, end):
        self.roiList = roiList
        self.regionNumber = regionNumber
        self.channelNumber = channelNumber
        self.start = start
        self.end = end

    def execute(self):
        roiList = self.roiList
        memento = roiList.getROI(self.regionNumber, self.channelNumber)
        roiList.setROI(self.regionNumber, self.channelNumber, self.start,
            self.end)
        return memento

    def undo(self, memento):
        start, end = memento
        self.roiList.setROI(self.regionNumber, self.channelNumber, start, end)


class LoadRoiCommand(Command):
    DESCRIPTION = 'Load ROI list'

    def __init__(self, roiList, fileName):
        self.roiList = roiList
        self.fileName = fileName

    def execute(self):
        roiList = self.roiList
        memento = roiList.rois.copy()

        try:
            inputStream = file(self.fileName, 'r')
            script = inputStream.read()
            inputStream.close()
        except IOError, e:
            if e.strerror:
                errmsg = e.strerror
            else:
                errmsg = str(e)

            raise CommandError('I/O Error',
                'Error loading ROI list from `%s\':\n%s',
                os.path.basename(self.fileName), errmsg)

        newList = RoiList.fromMotorScript(script)
        if newList.isEmpty():
            raise CommandError('I/O Error',
                ('Error loading ROI list: the file `%s\'\n'
                 'does not contain any region of interest commands.'),
                os.path.basename(self.fileName))
        else:
            roiList.rois[:] = newList.rois[:]
            return memento

    def undo(self, memento):
        self.roiList.rois[:] = memento
