#!/usr/bin/env python
# Name: test_spectra.py
# Purpose: Unit tests for libsetuproi.roiset.Spectra
# Author: Ken McIvor <mcivor@iit.edu>
#
# Copyright 2006 Illinois Institute of Technology
#
# See the file "LICENSE" for information on usage and redistribution
# of this file, and for a DISCLAIMER OF ALL WARRANTIES.

import unittest
from libsetuproi.spectra import Spectra


class TestSpectra(unittest.TestCase):
    def test_creation(self):
        s = Spectra('filename', None)

    def test_filename(self):
        s = Spectra('fileName', None)
        self.assertEquals('fileName', s.fileName)

    def test_no_channels(self):
        s = Spectra('', None)
        self.assertEquals((), s.channels)

    def test_channels(self):
        import Numeric
        A, B = 10, 3
        M = Numeric.arange(0.0, A*B, 1.0)
        M.shape = (A, B)
        s = Spectra('', M)
        self.assertEquals(B, len(s.channels))
        for i in range(0, B):
            self.assertEquals(M[:,i], s.channels[i])

    def test_loading_from_files(self):
        import os
        import Numeric
        import tempfile
        FILE_TEXT = ".0 1 2 3\n4 5 6 7\n8 9 10 11\n 12 13 14 15\n"
        fd, fname = tempfile.mkstemp()
        os.write(fd, FILE_TEXT)
        os.close(fd)

        try:
            s = Spectra.fromFile(fname)
        finally:
            os.unlink(fname)

        self.assertEquals(len(s.channels), 4)
        self.assert_(Numeric.alltrue(s.channels[1] == [1, 5, 9, 13]))

    def test_loading_bad_file(self):
        self.assertRaises(IOError, Spectra.fromFile, 'no_such_file.sff')


if __name__ == '__main__':
    unittest.main()
